/*
 * HPTalx
 * A PC<->HP48/49 communication program for Linux
 *
 * (C) 1999, 2000 by Bruno Barberi Gnecco
 * (C) 2005 by Bruno Barberi Gnecco, Rafael Ostertag
 *
 * $Id: gui.h,v 1.3 2007/09/29 21:21:01 guengel Exp $
 *
 *
 * Copyright note:
 *
 * This program is free software; you can
 * redistribute it and/or modify it under the
 * terms of the GNU General Public License as
 * published by the Free Software Foundation;
 * either version 2 of the License, or (at your
 * option) any later version.
 *
 * This program is distributed in the hope that
 * it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU
 * General Public License along with this
 * program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307 USA
 */

#ifndef GUI_H
#define GUI_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "hptalx.h"
#include "kermit.h"
#include "hpcomm.h"

/*
 * This used for creating and accessing the columns of the Files GtkTreeView 
 */
enum _file_list_columns
{
    FLC_TYPESTR,
    FLC_TYPE,
    FLC_NAME,
    FLC_SIZE,
    FLC_NUMBER
};
typedef enum _file_list_columns file_list_columns;

/*
 * This used for creating and accessing the columns of the Directories
 * GtkTreeView 
 */
enum _directory_list_columns
{
    DLC_NAME,
    DLC_NUMBER
};
typedef enum _directory_list_columns directory_list_columns;

/*
 * This struct is passed to the signal handler attached to the send button on 
 * the Command Window 
 */
struct _command_window_send_args
{
    const gchar        *command;
    GtkWidget          *output;
};
typedef struct _command_window_send_args command_window_send_args;

#define CWSA_P(a) ((command_window_send_args*)(a))
#define CWIA_P(a) ((command_window_internal_args*)(a))

extern GtkWidget   *dir_pc;
extern GtkWidget   *dir_hp;
extern GtkWidget   *files_pc;
extern GtkWidget   *files_hp;
extern GtkWidget   *pop_up_menu;
extern GtkItemFactory *item_factory;
extern GtkItemFactoryEntry items[];
extern const char  *on_items[];
extern const char  *off_items[];
extern const char  *hp49_items[];

extern void         gui_get_main_menu (GtkWidget * window,
				       GtkWidget ** menubar);
extern void         gui_set_menu_connected ();
extern void         gui_set_menu_disconnected ();
extern void         gui_get_pop_menu (GtkWidget * popmenu);

extern GtkWidget   *gui_backup_dialog_create (RETVALUE * ret_val);

extern void         gui_transfer_dialog_create (GtkWidget ** dialog,
						GtkWidget ** filelabel,
						GtkWidget ** infolabel,
						GtkWidget ** progressbar,
						int *cancel_flag);

extern void         gui_transfer_callback (unsigned int *bytes,
					   unsigned int *p, unsigned int *cps,
					   void *data);
extern void         gui_transfer_progress_bar_set_activity (GtkProgressBar *
							    pb);

extern GtkWidget   *gui_command_window_create (GCallback
					       send_command_handler);

extern void         gui_howtouse (GtkWidget * w, gpointer data);
extern void         gui_about (GtkWidget * w, gpointer data);

extern void         gui_print_nice_kstatus (k_status s);
extern void         gui_print_nice_hpstatus (hp_status s);

extern gboolean     gui_is_directory_selected ();
extern gboolean     gui_is_file_selected ();

extern void         gui_directory_list_create (GtkWidget ** list,
					       GtkWidget ** scroll_win,
					       VPANED what);

extern void         gui_file_list_create (GtkWidget ** list,
					  GtkWidget ** scroll_win,
					  VPANED what);

extern gboolean     gui_file_list_single_selection (GtkTreeView * list);
extern gchar       *gui_file_list_get_name_by_iter (GtkTreeModel * model,
						    GtkTreeIter * iter);
extern gchar       *gui_file_list_get_type_str_by_iter (GtkTreeModel * model,
							GtkTreeIter * iter);
extern gchar       *gui_file_list_get_size_str_by_iter (GtkTreeModel * model,
							GtkTreeIter * iter);

extern void
        gui_select_all_file_list_item (GtkWidget * w, gpointer wdc);

extern void
        gui_unselect_all_file_list_item (GtkWidget * w, gpointer wdc);

#endif
