
/*
 * HPTalx
 * A PC<->HP48/49 communication program for Linux
 *
 * (C) 1999 by Bruno Barberi Gnecco
 * (C) 2005 by Rafael Ostertag
 *
 *
 * $Id: main.c,v 1.3 2007/09/29 21:21:01 guengel Exp $
 *
 *
 * Copyright note:
 *
 * This program is free software; you can
 * redistribute it and/or modify it under the
 * terms of the GNU General Public License as
 * published by the Free Software Foundation;
 * either version 2 of the License, or (at your
 * option) any later version.
 *
 * This program is distributed in the hope that
 * it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU
 * General Public License along with this
 * program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307 USA
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "hptalx.h"
#include "gui.h"
#include "gui_utils.h"
#include "io.h"
#include "icons.h"
#include "setup.h"

#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <unistd.h>
#include <fcntl.h>

#define STRBUF 256

Pref                preferences;
struct data         data_pc;
struct data         data_hp;
HPANED              whereami_h;
VPANED              whereami_v;
CONNECTION          connected;
k_transfer_type     ttype = AUTO;
hp_calc             hp_calculator = HP_UNKNOWN;

/*--------------------------------------------------------------------------*/

int
main (int argc, char *argv[])
{
    GtkWidget          *window;
    GtkWidget          *main_vbox;
    GtkWidget          *vpaned, *hpaned;
    GtkWidget          *scrolled_win;
    GtkWidget          *menubar;

    gtk_init (&argc, &argv);

    load_prefs ();

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    g_signal_connect (GTK_OBJECT (window), "destroy",
		      G_CALLBACK (io_disconnect), (void *) K_FULL_QUIT);
    g_signal_connect (GTK_OBJECT (window), "destroy",
		      G_CALLBACK (gtk_main_quit), "WM destroy");
    gtk_window_set_title (GTK_WINDOW (window), "HP Talx " PACKAGE_VERSION);
    gtk_widget_set_usize (window, 640, 480);
    main_vbox = gtk_vbox_new (FALSE, 1);
    gtk_container_border_width (GTK_CONTAINER (main_vbox), 1);
    gtk_container_add (GTK_CONTAINER (window), main_vbox);
    gtk_widget_show (main_vbox);

    /*
     * menu 
     */
    gui_get_main_menu (window, &menubar);
    gtk_box_pack_start (GTK_BOX (main_vbox), menubar, FALSE, TRUE, 0);
    gtk_widget_show (menubar);

    /*
     * popmenu 
     */
    pop_up_menu = gtk_menu_new ();
    gui_get_pop_menu (pop_up_menu);

    /*
     * toolbar 
     */

    /*
     * file selectors 
     */
    vpaned = gtk_vpaned_new ();
    gtk_container_add (GTK_CONTAINER (main_vbox), vpaned);
    gtk_paned_set_gutter_size (GTK_PANED (vpaned), 10);
    gtk_widget_show (vpaned);

    /*
     * First PC
     */
    hpaned = gtk_hpaned_new ();
    gtk_paned_set_gutter_size (GTK_PANED (hpaned), 10);
    gtk_paned_add1 (GTK_PANED (vpaned), hpaned);
    gtk_widget_show (hpaned);

    /*
     * The PC directories list
     */
    gui_directory_list_create (&dir_pc, &scrolled_win, PC);
    gtk_paned_add1 (GTK_PANED (hpaned), scrolled_win);

    /*
     * The PC files list 
     */
    gui_file_list_create (&files_pc, &scrolled_win, PC);
    gtk_paned_add2 (GTK_PANED (hpaned), scrolled_win);

    /*
     * Now HP 
     */
    hpaned = gtk_hpaned_new ();
    gtk_paned_set_gutter_size (GTK_PANED (hpaned), 10);
    gtk_paned_add2 (GTK_PANED (vpaned), hpaned);
    gtk_widget_show (hpaned);

    /*
     * The HP directories list 
     */
    gui_directory_list_create (&dir_hp, &scrolled_win, HP);
    gtk_paned_add1 (GTK_PANED (hpaned), scrolled_win);

    /*
     * The HP files clist 
     */

    gui_file_list_create (&files_hp, &scrolled_win, HP);
    gtk_paned_add2 (GTK_PANED (hpaned), scrolled_win);

    /*
     * initialize stuff
     */
    status_bar_create (main_vbox);
    gui_set_menu_disconnected ();
    init_pixbufs ();
    data_pc.current = NULL;
    data_pc.dir = NULL;
    data_pc.filename = NULL;
    data_pc.file_type_str = NULL;
    data_hp.current = NULL;
    data_hp.dir = NULL;
    data_hp.filename = NULL;
    data_hp.file_type_str = NULL;
    connected = OFFLINE;
    data_pc.current = getcwd (NULL, 0);

    /*
     * Show main window 
     */
    gtk_widget_show (window);

    /*
     * Fill values into the PC Pane 
     */
    io_refresh (NULL, GINT_TO_POINTER (PC));

    whereami_v = PC;

    if (preferences.start_connected == TRUE)
	io_connect (NULL, NULL);

    gtk_main ();

    return 0;
}
